@@ -102,7 +102,8 @@ def mentions_to_indices(files, indices, event_title):  # pragma: no cover
 @click.option('-f', '--files', default='./editions/*.xml', show_default=True)  # pragma: no cover
 @click.option('-i', '--indices', default='./indices/list*.xml', show_default=True)  # pragma: no cover
 @click.option('-t', '--event-title', default='erwähnt in ', show_default=True)  # pragma: no cover
-def denormalize_indices(files, indices, event_title):  # pragma: no cover
+@click.option('-x', '--title-xpath', default='.//tei:title/text()', show_default=True)  # pragma: no cover
+def denormalize_indices(files, indices, event_title, title_xpath):  # pragma: no cover
     """Write pointers to mentions in index-docs and copy index entries into docs"""
     files = sorted(glob.glob(files))
     index_files = sorted(glob.glob(indices))
@@ -120,7 +121,7 @@ def denormalize_indices(files, indices, event_title):  # pragma: no cover
         doc_base = doc.any_xpath('./@xml:base')[0]
         doc_id = doc.any_xpath('./@xml:id')[0]
         doc_uri = f"{doc_base}/{doc_id}"
-        doc_title = doc.any_xpath('.//tei:title[@type="main"]/text()')[0]
+        doc_title = doc.any_xpath(title_xpath)[0]
         refs = doc.any_xpath('.//tei:rs[@ref]/@ref')
         for ref in refs:
             ref_doc_dict[ref[1:]].append({
@@ -187,6 +188,16 @@ def denormalize_indices(files, indices, event_title):  # pragma: no cover
                 back_node.append(list_place)
                 for ent in ent_dict[key]:
                     list_place.append(ent)
+            if key.endswith('org'):
+                list_org = ET.Element("{http://www.tei-c.org/ns/1.0}listOrg")
+                back_node.append(list_org)
+                for ent in ent_dict[key]:
+                    list_org.append(ent)
+            if key.endswith('bibl'):
+                list_bibl = ET.Element("{http://www.tei-c.org/ns/1.0}listBibl")
+                back_node.append(list_bibl)
+                for ent in ent_dict[key]:
+                    list_bibl.append(ent)
         root_node.append(back_node)
         doc.tree_to_file(file=x)
     click.echo(
